@@ -1206,7 +1206,8 @@ C_Int64 CoreArray::SysHandleSeek(TSysHandle Handle, C_Int64 Offset,
 		else
 			return li.QuadPart;
 	#else
-		#if defined(COREARRAY_CYGWIN) || defined(COREARRAY_PLATFORM_MACOS) || defined(COREARRAY_PLATFORM_BSD)
+		#if defined(COREARRAY_CYGWIN) || defined(COREARRAY_PLATFORM_MACOS) || defined(COREARRAY_PLATFORM_BSD) || (defined(COREARRAY_PLATFORM_LINUX) && (!defined(__GLIBC__) || defined(__MUSL__)))
+			// defined(COREARRAY_PLATFORM_LINUX) && !defined(__GLIBC__) intends to include MUSL
 			return lseek(Handle, Offset, sk);
 		#else
 			return lseek64(Handle, Offset, sk);
@@ -1222,7 +1223,8 @@ bool CoreArray::SysHandleSetSize(TSysHandle Handle, C_Int64 NewSize)
 		else
 			return false;
 	#else
-		#if defined(COREARRAY_CYGWIN) || defined(COREARRAY_PLATFORM_MACOS) || defined(COREARRAY_PLATFORM_BSD)
+		#if defined(COREARRAY_CYGWIN) || defined(COREARRAY_PLATFORM_MACOS) || defined(COREARRAY_PLATFORM_BSD) || (defined(COREARRAY_PLATFORM_LINUX) && (!defined(__GLIBC__) || defined(__MUSL__)))
+			// defined(COREARRAY_PLATFORM_LINUX) && !defined(__GLIBC__) intends to include MUSL
 			return ftruncate(Handle, NewSize)==0;
 		#else
 			return ftruncate64(Handle, NewSize)==0;
